@@ -27,7 +27,10 @@ Syntax::
 
 import logging
 from xml.dom import minidom
-from docutils import nodes
+try:
+    from docutils import nodes
+except ImportError:
+    logging.warn("You need install docutils library")
 from docutils.core import publish_parts
 from docutils.parsers.rst import directives, Directive
 from pygments.formatters import HtmlFormatter
